{ pkgs, config, lib, ... }:

{
  # Bash usability & speed settings
  # Auto-complete for bash commands and flags (press Tab!)
  programs.bash.completion.enable = true; # Optional
  # Adds color to your 'ls' command (makes folders, files, etc. colorful)
  programs.bash.enableLsColors = true; # Optional
  # Lets you search for commands from packages you haven't installed yet (via `nix-index`)
  programs.nix-index.enableBashIntegration = true; # Optional

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    # drivers for sound
    sof-firmware

    # terminal apps
    wget
    curl
    fastfetch
    git
    btop
    htop
    tree
    restic # backup program
    wiper # A TUI disk analyser and cleanup tool
    curl
    inxi #debugging
    systemctl-tui # systemd tui

    # emulation
    quickemu

    #emulation
    distrobox

    # terminal editors
    neovim
    xclip # for nvim clipboard
    ptyxis

    # nix helper apps
    nh

    # core apps
    iotas # nextcloud compatible notes app
    keepassxc # password client
    nextcloud-client
    calibre # ebook program
    libreoffice-fresh # word docs
    hunspell # dictionaries for libreoffice
    hunspellDicts.en_CA
    hunspellDicts.en_US
    xreader # pdf viewer
    pdftk # pdf editor
 
    # creative apps
    kdePackages.kdenlive
    gimp
    pkgs.krita
    element-desktop

    # music apps
    yt-dlp
    audacity

    #gaming
    dosbox

    #gpu tools
    intel-gpu-tools
    #nvtopPackages.full not working right now

    # archive programs
    zip
    xz
    unzip
    p7zip

    # utils
    ripgrep # recursively searches directories for a regex >
    #jq # A lightweight and flexible command-line JSON proc>
    #yq-go # yaml processor https://github.com/mikefarah/yq
    eza # A modern replacement for ‘ls’
    #fzf # A command-line fuzzy finder
    nnn # terminal file manager

    # networking tools
    mtr # A network diagnostic tool
    iperf3
    dnsutils  # `dig` + `nslookup`
    #ldns # replacement of `dig`, it provide the command `drill`
    #aria2 # A lightweight multi-protocol & multi-source command-line download utility
    #socat # replacement of openbsd-netcat
    nmap # A utility for network discovery and security auditing
    #ipcalc  # it is a calculator for the IPv4/v6 addresses

    # system tools
    sysstat
    lm_sensors # for `sensors` command
    ethtool
    pciutils # lspci
    usbutils # lsusb

    # system call monitoring
    strace # system call monitoring
    ltrace # library call monitoring
    lsof # list open files

    iotop # io monitoring
    iftop # network monitoring

  ];

}
